==> haskell-hasql-pool-0.5.0.1-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.5.0.1
id: hasql-pool-0.5.0.1-CnMcV8qGN3Y9FYH5fF7HTB
key: hasql-pool-0.5.0.1-CnMcV8qGN3Y9FYH5fF7HTB
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
abi: 0d0e068e325610e011a3823adae4fcb2
exposed: True
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs: /usr/lib/ghc-8.6.4/site-local/hasql-pool-0.5.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hasql-pool-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hasql-pool-0.5.0.1
hs-libraries: HShasql-pool-0.5.0.1-CnMcV8qGN3Y9FYH5fF7HTB
depends:
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    hasql-1.3.0.3-93vrZjJh84d5IkrTd8ijCN
    resource-pool-0.2.3.2-AXn8xEuRp43LL2wvdwh43k time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.5.0.1-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.5.0.1
id: hasql-pool-0.5.0.1-3KXaOCdcZGdLQNxl33Jdez
key: hasql-pool-0.5.0.1-3KXaOCdcZGdLQNxl33Jdez
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
abi: cc1ab1bceb8386dec959fc1c7f580075
exposed: True
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs: /usr/lib/ghc-8.6.4/site-local/hasql-pool-0.5.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/hasql-pool-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/hasql-pool-0.5.0.1
hs-libraries: HShasql-pool-0.5.0.1-3KXaOCdcZGdLQNxl33Jdez
depends:
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    hasql-1.3.0.3-DErnYN58oeXCr3K5oAQHVj
    resource-pool-0.2.3.2-3cYc01LVkoX31JGtXl5zx5 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
